@@ -34,6 +34,7 @@ def ec2_prepare_node(region, account_id, cytoscape_node_data):
                 "LaunchTime": LaunchTime,
                 "InstanceType": InstanceType,
                 "tag": ec2_tag,
-                "cost_for_month": "64.54 USD"
+                "console_url" : "https://"+"region+.console.aws.amazon.com/ec2/v2/home?region="+region+"#InstanceDetails:instanceId="+ec2Id,
+                "cost_for_month": 6.30
             }
         })
